# Contributors

## Authors
- Martin Fitzner (Merck KGaA, Darmstadt, Germany), [Contact](mailto:martin.fitzner@merckgroup.com), [Github](https://github.com/Scienfitz)
- Adrian Šošić (Merck Life Science KGaA, Darmstadt, Germany), [Contact](mailto:adrian.sosic@merckgroup.com), [Github](https://github.com/AdrianSosic)
- Alexander Hopp (Merck KGaA, Darmstadt, Germany) [Contact](mailto:alexander.hopp@merckgroup.com), [Github](https://github.com/AVHopp)
- Alex Lee (EMD Electronics, Tempe, Arizona, USA) [Contact](mailto:alex.lee@emdgroup.com), [Github](https://github.com/galaxee87)

## Contributors
- Daniel Weber (Merck KGaA, Darmstadt, Germany):  
  Telemetry prototype
- Emeline Sola (during an internship at Merck KGaA, Darmstadt, Germany):  
  Auto-documentation of the examples
- Sourabh Agrawal (Sigma-Aldrich Chemicals Private Limited):
  Initial implementation of additional surrogate models and clustering methods
- Julie Fang (Merck Life Science KGaA, Darmstadt, Germany):  
  Farthest point sampling
- Roya Javadi (Vector Institute, Toronto, Canada):
  Import optimization
- Sterling Baird (Acceleration Consortium, Toronto, Canada):
  Documentation and general feedback
